"use client";
import { Box, Grid, GridItem, Heading, Link as ChakraLink, Stack, Text, VisuallyHidden } from "@chakra-ui/react";

// import { chain } from "lodash";
import Link from "next/link";
import { Fragment } from "react";
import { MdDarkMode } from "react-icons/md";

function GridColumnHeading({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <Heading as="h3" fontSize="sm" fontWeight="semibold" color="secondary.500" letterSpacing="wider" textTransform="uppercase">
      {children}
    </Heading>
  );
}

const Links = ({ links }: { links: string[] }) => {
  return (
    <Fragment>
      {links.map((link:string, index:number) => (
        <li key={index}>
          <ChakraLink
            href={link}
            as={Link}
            color="primary.300"
            _hover={{
              color: "primary.500",
            }}
            noOfLines={1}>
            {link}
          </ChakraLink>
        </li>
      ))}
    </Fragment>
  );
};

function GridColumn({ links, title, column = 1, hasPrimaryLinks }: { links: string[]; title: string; hasPrimaryLinks: boolean; column?: number }) {
  if (links == null) return null;
  if (column == 2) {
    return (
      <Box>
        <GridColumnHeading>{title}</GridColumnHeading>
        <Grid as="ul" mt={4} templateColumns="repeat(2, 1fr)" gap={4}>
          <Links links={links} />
        </Grid>
      </Box>
    );
  }
  const stackProps = {
    justifyContent: {
      base: !hasPrimaryLinks && title?.toLowerCase() == "quick links" ? "auto" : "auto",
      md: !hasPrimaryLinks && title?.toLowerCase() == "quick links" ? "end" : "auto",
    },
  };

  return (
    <Box>
      <GridColumnHeading>{title}</GridColumnHeading>
      <Stack as="ul" mt={4} spacing={4} direction={"column"} {...stackProps}>
        <Links links={links} />
      </Stack>
    </Box>
  );
}

export default function Footer({ hasPrimaryLinks = true }) {
  // const router = useRouter();

  const internal_links = {
    title: "Internal Links",
    links: ["Documentaries", "Themes", "Chrome Cast"],
  };

  const external_links = {
    title: "Enterprise",
    links: ["Download Chrome Browser", "Chrome Browser For Enterprise", "ChromeOs", "Google Cloud", "Google Workspace"],
  };

  return (
    <Box as="footer" bg="wildSand.500" aria-labelledby="footerHeading">
      {/* <Drift appId="3544udmum4wh" /> */}
      <VisuallyHidden as="h2" id="footerHeading">
        Footer
      </VisuallyHidden>

      <Box maxW="7xl" mx="auto" py={{ base: 12, lg: 16 }} px={[4, 6, null, 8]}>
        <Box pb={8} display={{ xl: "grid" }} gridTemplateColumns={{ xl: "repeat(1, 1fr)" }} gridGap={{ xl: 8 }}>
          <Grid
            justifyContent={{ base: "auto", sm: "auto" }}
            gridTemplateColumns={{
              base: !hasPrimaryLinks ? "repeat(1, 1fr)" : "repeat(2, 1fr)",
              md: !hasPrimaryLinks ? "repeat(2, 1fr)" : "repeat(5, 1fr)",
            }}
            gridGap={8}>
            <GridItem>
              <GridColumn links={internal_links.links} title={internal_links.title} hasPrimaryLinks={hasPrimaryLinks} />
            </GridItem>
            <GridItem>
              <GridColumn links={external_links.links} title={external_links.title} hasPrimaryLinks={hasPrimaryLinks} />
            </GridItem>
            <GridItem>
              <GridColumn links={internal_links.links} title={internal_links.title} hasPrimaryLinks={hasPrimaryLinks} />
            </GridItem>
            <GridItem>
              <GridColumn links={external_links.links} title={external_links.title} hasPrimaryLinks={hasPrimaryLinks} />
            </GridItem>
            <GridItem>
              <GridColumn links={internal_links.links} title={internal_links.title} hasPrimaryLinks={hasPrimaryLinks} />
            </GridItem>
          </Grid>
        </Box>

        <Box mt={7} pt={8} borderTopWidth="1px" borderColor="primary.700" display={{ md: "flex" }} alignItems={{ md: "end" }} justifyContent={{ md: "space-between" }}>
          <Stack direction="row" display="flex" spacing={6} order={{ md: 2 }}>
            <ChakraLink
              color="primary.400"
              _hover={{
                color: "primary.300",
              }}>
              <VisuallyHidden>dark mode</VisuallyHidden>
              <Box as={MdDarkMode} w={6} h={6} />
            </ChakraLink>
          </Stack>

          <Box>
            <Stack direction="row" display="flex" flexWrap="wrap" justifyContent={{ base: "auto", sm: "auto" }}>
              <Text color={"primary.500"} fontSize={"lg"} fontWeight={"bold"}>
                Logo Here
              </Text>
              <ChakraLink
                as={Link}
                href="#"
                px={4}
                color="secondary.500"
                variant={"solid"}
                sx={{
                  // Apply custom styles using Chakra's sx prop
                  _hover: {
                    // Apply styles on hover
                    borderBottomColor: "blue.500",
                    borderBottomWidth: "2px",
                  },
                }}>
                Privacy Policy
              </ChakraLink>
              <ChakraLink
                as={Link}
                href="#"
                px={4}
                color="secondary.500"
                variant={"solid"}
                sx={{
                  // Apply custom styles using Chakra's sx prop
                  _hover: {
                    // Apply styles on hover
                    borderBottomColor: "blue.500",
                    borderBottomWidth: "2px",
                  },
                }}>
                Terms and Condition
              </ChakraLink>
              <ChakraLink
                as={Link}
                href="#"
                px={4}
                color="secondary.500"
                variant={"solid"}
                sx={{
                  // Apply custom styles using Chakra's sx prop
                  _hover: {
                    // Apply styles on hover
                    borderBottomColor: "blue.500",
                    borderBottomWidth: "2px",
                  },
                }}>
                Cookies Policy
              </ChakraLink>
              <ChakraLink
                as={Link}
                href="#"
                px={4}
                color="secondary.500"
                variant={"solid"}
                sx={{
                  // Apply custom styles using Chakra's sx prop
                  _hover: {
                    // Apply styles on hover
                    borderBottomColor: "blue.500",
                    borderBottomWidth: "2px",
                  },
                }}>
                About us
              </ChakraLink>
              <ChakraLink
                as={Link}
                href="#"
                px={4}
                color="secondary.500"
                variant={"solid"}
                sx={{
                  // Apply custom styles using Chakra's sx prop
                  _hover: {
                    // Apply styles on hover
                    borderBottomColor: "blue.500",
                    borderBottomWidth: "2px",
                  },
                }}>
                EULA
              </ChakraLink>
              <ChakraLink
                as={Link}
                href="#"
                px={4}
                color="secondary.500"
                variant={"solid"}
                sx={{
                  // Apply custom styles using Chakra's sx prop
                  _hover: {
                    // Apply styles on hover
                    borderBottomColor: "blue.500",
                    borderBottomWidth: "2px",
                  },
                }}>
                Contact
              </ChakraLink>
            </Stack>
          </Box>
        </Box>
      </Box>
    </Box>
  );
}
